/* eslint-disable-next-line no-unused-vars */ // used in osc-rest-manager
function fixHtmlStandardText(content) {
  // html standard text has '&nbsp; ' tabs and <div>&nbsp;</div> for *some* linebreaks
  const fixedContent = _fixHtmlTabs(content);
  return _fixHtmlLinebreaks(fixedContent);
}

/* eslint-disable-next-line no-unused-vars */ // used in thread
function fixHtmlThread(content) {
  // html threads have no tabs but have  <div>&nbsp;</div> for *some* linebreaks
  return _fixHtmlLinebreaks(content);
}

/* eslint-disable-next-line no-unused-vars */ // used in osc-rest-manager, thread
function fixPlaintext(content) {
  // plaintext standard text has no tabs and \n linebreaks
  return _fixPlaintextLinebreaks(content);
}

/* eslint-disable-next-line no-unused-vars */ // used in lio-rest-manager
function tagVariables(content) {
  /* wrap variables in notranslate spans so the translation engine doesn't make them invalid, ex. by
   adding a space between the variable indicator $ and the name of the variable */

  /* matches substrings that are preceded by whitespace/newline/beginning of string, starts with
  a '$', followed by at least one letter, and then any number of letters, numbers, and/or '_'
  maybe be broken up one or more times by '.' but only if there is a letter/number/_ before and
  after.
  includes content like: '$contacts.name.first', '$VaRiable', $valid_variable_0___ */
  const variableRegex = /(\$(?:[A-Za-z]+[A-Za-z0-9_]*)(?:\.?[A-Za-z0-9_])*)/gm;
  return content.replace(variableRegex, '<span class="notranslate">$1</span>');
}

function _fixPlaintextLinebreaks(content) {
  // convert \n newlines to <br> tags so that they'll display properly in our extension + the BUI
  return content.replace(/(\n)/gi, "<br>");
}

function _fixHtmlLinebreaks(content) {
  // wrap non-breaking space newlines in notranslate spans so translation engines don't remove them
  // the non-breaking spaces can be encoded as &#160; or &nbsp; depending on source
  return content.replace(/(<div>(&#160;|&nbsp;)<\/div>)/gi, "<br>");
}

function _fixHtmlTabs(content) {
  /* matches any number of non-breaking spaces (encoded by OSC as '&#160;') and normal spaces */
  return content.replace(/((?:&#160; )+)/g, '<span class="notranslate">$1</span>');
}

function stripHtmlTags(content) {
  // Create a temporary DOM element
  let tempDiv = document.createElement('div');
  tempDiv.innerHTML = content;
  
  // Remove all script and style elements
  let scriptTags = tempDiv.getElementsByTagName('script');
  for (let i = scriptTags.length - 1; i >= 0; i--) {
    scriptTags[i].parentNode.removeChild(scriptTags[i]);
  }
  
  let styleTags = tempDiv.getElementsByTagName('style');
  for (let i = styleTags.length - 1; i >= 0; i--) {
    styleTags[i].parentNode.removeChild(styleTags[i]);
  }
  
  // Get the inner text and return
  return tempDiv.innerText || '';
}

function getWordCount(text){
    // deal with special case for Chinese
    let originalLength = text.length;
    // Strip Chinese characters and compare the differences in the lengths 
    // to determine a Chinese word count.
    text= text.replaceAll("[\\u4e00-\\u9fff\\uf900-\\ufaff]", "");
    // According the following article every 1000 Chinese characters
    // equates to about 600 to 700 words, so we multiply the Chinese 
    // character count by 0.65 to account for this.
    // https://www.actranslation.com/chinese/chinese-wordcount.htm
    let nonDelimitedWordCount = Math.round((originalLength - text.length) * 0.65);
  
    // calc word count excluding Chinese
    // remove extra spaces, e.g., multiple consecutive spaces should be
    // consolidated into one space.
    // split words into array/list of words
    let words = text.split(/\s+/).filter(word => word !== '');
    let wordCount = words.length;
    // finally returns actual word count
    return wordCount + nonDelimitedWordCount;
}
